OppiaMobile Server Change Log
================================

v0.7.3 - not yet released
-----------------------------
* https://github.com/DigitalCampus/django-oppia/issues/issue/224 - view for cohort activity 


v0.7.2 - released 29 Mar 2015
------------------------------
* https://github.com/DigitalCampus/django-oppia/issues/issue/220 - update course list display
* https://github.com/DigitalCampus/django-oppia/issues/issue/193 - move to Django 1.7
* https://github.com/DigitalCampus/django-oppia/issues/issue/223 - Cohort can now be linked to multiple courses

v0.7.1 - released 18 Feb 2015
------------------------------
* https://github.com/DigitalCampus/django-oppia/issues/issue/170 - publishing directly via API


v0.7.0 - released 11 Feb 2015
------------------------------
* https://github.com/DigitalCampus/django-oppia/issues/issue/213 - reset password using email address
* https://github.com/DigitalCampus/moodle-block_oppia_mobile_export/issues/issues/issue/117 - add support for Moodle url activities
* https://github.com/DigitalCampus/django-oppia/issues/issue/141 - remove course download model
* https://github.com/DigitalCampus/django-oppia/issues/issue/129 - visualisation menu update
* https://github.com/DigitalCampus/django-oppia/issues/issue/215 - add course manager model

v0.6.0 - released 22 Dec 2014
------------------------------
* https://github.com/DigitalCampus/django-oppia/issues/211 - save phone no on register via API
* https://github.com/DigitalCampus/django-oppia/issues/212 - Fix quiz titles

Previous Versions
------------------

.. toctree::
   :maxdepth: 2
   
   changelog_server_v0.5
   changelog_server_v0.4
   changelog_server_v0.3
   changelog_server_v0.2
   changelog_server_v0.1
